@@ -10,35 +10,31 @@
     FOR A PARTICULAR PURPOSE.  See the GNU GPL for more details.
 */
 
-/* exported init,enable,disable,Indicator */
+
 'use strict';
 
-const GObject = imports.gi.GObject;
-const St = imports.gi.St;
-const Meta = imports.gi.Meta;
-const Shell = imports.gi.Shell;
+import GObject from 'gi://GObject';
+import St from 'gi://St';
+import Meta from 'gi://Meta';
+import Shell from 'gi://Shell';
 // https://gitlab.gnome.org/GNOME/gnome-shell/-/blob/main/js/ui/panelMenu.js
-const PanelMenu = imports.ui.panelMenu;
-const Clutter = imports.gi.Clutter;
-const PopupMenu = imports.ui.popupMenu;
-const Slider = imports.ui.slider;
-const Main = imports.ui.main;
+import * as PanelMenu from 'resource:///org/gnome/shell/ui/panelMenu.js';
+import Clutter from 'gi://Clutter';
+import * as PopupMenu from 'resource:///org/gnome/shell/ui/popupMenu.js';
+import * as Slider from 'resource:///org/gnome/shell/ui/slider.js';
+import * as Main from 'resource:///org/gnome/shell/ui/main.js';
 
-const ExtensionUtils = imports.misc.extensionUtils;
-const Me = ExtensionUtils.getCurrentExtension();
+import {Extension, gettext as _} from 'resource:///org/gnome/shell/extensions/extension.js';
 
-const Domain = imports.gettext.domain(Me.metadata['gettext-domain']);
-const _ = Domain.gettext;
-
-const Lib = Me.imports.convenience;
-const Settings = Me.imports.settings;
-const Time = Me.imports.timer;
-const UtilRecorder = Me.imports.utilrecorder;
-const UtilAudio = Me.imports.utilaudio;
-const UtilWebcam = Me.imports.utilwebcam;
-const UtilNotify = Me.imports.utilnotify;
-const Selection = Me.imports.selection;
-const UtilExeCmd = Me.imports.utilexecmd;
+import * as Lib from './convenience.js';
+import * as Settings from './settings.js';
+import * as Time from './timer.js';
+import * as UtilRecorder from './utilrecorder.js';
+import * as UtilAudio from './utilaudio.js';
+import * as UtilWebcam from './utilwebcam.js';
+import * as UtilNotify from './utilnotify.js';
+import * as Selection from './selection.js';
+import * as UtilExeCmd from './utilexecmd.js';
 
 var Indicator;
 let timerD = null;
@@ -55,33 +51,31 @@ let keybindingConfigured = false;
 const EasyScreenCastIndicator = GObject.registerClass({
     GTypeName: 'EasyScreenCast_Indicator',
 }, class EasyScreenCastIndicator extends PanelMenu.Button {
-    /**
-     * @private
-     */
-    _init() {
-        super._init(null, 'EasyScreenCast_Indicator');
+    constructor(extension) {
+        super(null, 'EasyScreenCast_Indicator');
 
-        this._settings = new Settings.Settings();
-        Lib.debugEnabled = this._settings.getOption('b', Settings.VERBOSE_DEBUG_SETTING_KEY);
+        this._extension = extension;
+        this._settings = new Settings.Settings(this._extension.getSettings());
+        Lib.setDebugEnabled(this._settings.getOption('b', Settings.VERBOSE_DEBUG_SETTING_KEY));
         this._settings._settings.connect(
             `changed::${Settings.VERBOSE_DEBUG_SETTING_KEY}`,
             () => {
-                Lib.debugEnabled = this._settings.getOption('b', Settings.VERBOSE_DEBUG_SETTING_KEY);
+                Lib.setDebugEnabled(this._settings.getOption('b', Settings.VERBOSE_DEBUG_SETTING_KEY));
             }
         );
 
         this.CtrlAudio = new UtilAudio.MixerAudio();
-        this.CtrlWebcam = new UtilWebcam.HelperWebcam();
+        this.CtrlWebcam = new UtilWebcam.HelperWebcam(_('Unspecified webcam'));
 
         this.CtrlNotify = new UtilNotify.NotifyManager();
         this.CtrlExe = new UtilExeCmd.ExecuteStuff(this);
 
         // load indicator icons
         this._icons = {
-            on: Lib.loadIcon('icon_recording.svg'),
-            onSel: Lib.loadIcon('icon_recordingSel.svg'),
-            off: Lib.loadIcon('icon_default.svg'),
-            offSel: Lib.loadIcon('icon_defaultSel.svg'),
+            on: Lib.loadIcon(this._extension.dir, 'icon_recording.svg'),
+            onSel: Lib.loadIcon(this._extension.dir, 'icon_recordingSel.svg'),
+            off: Lib.loadIcon(this._extension.dir, 'icon_default.svg'),
+            offSel: Lib.loadIcon(this._extension.dir, 'icon_defaultSel.svg'),
         };
 
         // check audio
@@ -102,11 +96,10 @@ const EasyScreenCastIndicator = GObject.registerClass({
         );
 
         // prepare setting var
-        if (this._settings.getOption('i', Settings.TIME_DELAY_SETTING_KEY) > 0) {
+        if (this._settings.getOption('i', Settings.TIME_DELAY_SETTING_KEY) > 0)
             this.isDelayActive = true;
-        } else {
+        else
             this.isDelayActive = false;
-        }
 
 
         // Add the title bar icon and label for time display
@@ -122,8 +115,8 @@ const EasyScreenCastIndicator = GObject.registerClass({
             y_align: Clutter.ActorAlign.CENTER,
         });
 
-        this.indicatorBox.add_actor(this.timeLabel);
-        this.indicatorBox.add_actor(this.indicatorIcon);
+        this.indicatorBox.add_child(this.timeLabel);
+        this.indicatorBox.add_child(this.indicatorIcon);
 
         // init var
         this.recorder = new UtilRecorder.CaptureVideo();
@@ -175,9 +168,8 @@ const EasyScreenCastIndicator = GObject.registerClass({
          * @param {number} number a number
          */
         function padZeros(number) {
-            if (number < 10) {
+            if (number < 10)
                 number = `0${number}`;
-            }
 
             return number.toString();
         }
@@ -215,9 +207,8 @@ const EasyScreenCastIndicator = GObject.registerClass({
         } else {
             Lib.TalkativeLog('-*-right click indicator');
 
-            if (this.menu.isOpen) {
+            if (this.menu.isOpen)
                 this.menu.close();
-            }
 
             this.isShowNotify = this._settings.getOption('b', Settings.SHOW_NOTIFY_ALERT_SETTING_KEY);
             this._doRecording();
@@ -238,9 +229,8 @@ const EasyScreenCastIndicator = GObject.registerClass({
      * null.
      */
     _addWebcamSubMenu() {
-        if (this.CtrlWebcam === null) {
-            this.CtrlWebcam = new UtilWebcam.HelperWebcam();
-        }
+        if (this.CtrlWebcam === null)
+            this.CtrlWebcam = new UtilWebcam.HelperWebcam(_('Unspecified webcam'));
 
         // add sub menu webcam recording
         this._populateSubMenuWebcam();
@@ -256,9 +246,8 @@ const EasyScreenCastIndicator = GObject.registerClass({
         let arrMI = this._createMIWebCam();
 
         this.smWebCam.menu.removeAll();
-        for (let element in arrMI) {
+        for (let element in arrMI)
             this.smWebCam.menu.addMenuItem(arrMI[element]);
-        }
 
         let i = this._settings.getOption('i', Settings.DEVICE_INDEX_WEBCAM_SETTING_KEY);
         Lib.TalkativeLog(`-*-populated submenuwebcam. Settings i=${i}`);
@@ -300,9 +289,8 @@ const EasyScreenCastIndicator = GObject.registerClass({
 
         Lib.TalkativeLog('-*-add new items to sub menu audio');
         var arrMI = this._createMIAudioRec();
-        for (var ele in arrMI) {
+        for (var ele in arrMI)
             this.sub_menu_audio_recording.menu.addMenuItem(arrMI[ele]);
-        }
     }
 
     /**
@@ -323,9 +311,8 @@ const EasyScreenCastIndicator = GObject.registerClass({
         this.sub_menu_area_recording.icon.icon_name = 'view-fullscreen-symbolic';
 
         var arrMI = this._createMIAreaRec();
-        for (var ele in arrMI) {
+        for (var ele in arrMI)
             this.sub_menu_area_recording.menu.addMenuItem(arrMI[ele]);
-        }
 
         this.sub_menu_area_recording.label.text = this.AreaType[this._settings.getOption('i', Settings.AREA_SCREEN_SETTING_KEY)];
         this.menu.addMenuItem(this.sub_menu_area_recording);
@@ -339,9 +326,8 @@ const EasyScreenCastIndicator = GObject.registerClass({
         this.smDelayRec.icon.icon_name = 'alarm-symbolic';
 
         var arrMI = this._createMIInfoDelayRec();
-        for (var ele in arrMI) {
+        for (var ele in arrMI)
             this.smDelayRec.menu.addMenuItem(arrMI[ele]);
-        }
 
         var secDelay = this._settings.getOption('i', Settings.TIME_DELAY_SETTING_KEY);
         if (secDelay > 0) {
@@ -481,9 +467,8 @@ const EasyScreenCastIndicator = GObject.registerClass({
         ];
         // add menu item audio source from PA
         var audioList = this.CtrlAudio.getListInputAudio();
-        for (var index in audioList) {
+        for (var index in audioList)
             this.AudioChoice.push(audioList[index]);
-        }
 
         this.AudioMenuItem = new Array(this.AudioChoice.length);
 
@@ -556,7 +541,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
                 ).toString() + _(' Sec'),
         });
         this.DelayTimeTitle.actor.add_child(this.DelayTimeLabel);
-        this.DelayTimeTitle.align = St.Align.END;
+        // TODO this.DelayTimeTitle.align = St.Align.END;
 
         this.imSliderDelay = new PopupMenu.PopupBaseMenuItem({
             activate: false,
@@ -576,7 +561,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
             this._onDelayTimeChanged()
         );
 
-        this.imSliderDelay.add(this.TimeSlider);
+        this.imSliderDelay.actor.add_child(this.TimeSlider);
 
         return [this.DelayTimeTitle, this.imSliderDelay];
     }
@@ -605,7 +590,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
         this.CtrlWebcam.startMonitor();
 
         // add indicator
-        this.add_actor(this.indicatorBox);
+        this.add_child(this.indicatorBox);
     }
 
     /**
@@ -616,9 +601,11 @@ const EasyScreenCastIndicator = GObject.registerClass({
         this._removeKeybindings();
         // stop monitoring inputvideo
         this.CtrlWebcam.stopMonitor();
+        // unregister mixer control
+        this.CtrlAudio.destroy();
 
         // remove indicator
-        this.remove_actor(this.indicatorBox);
+        this.remove_child(this.indicatorBox);
     }
 
     /**
@@ -812,14 +799,14 @@ const EasyScreenCastIndicator = GObject.registerClass({
             if (alertEnd) {
                 this.CtrlNotify.updateNotify(
                     this.notifyCounting,
-                    _(`EasyScreenCast -> Finish Recording / Seconds : ${sec}`),
+                    _(`Finish Recording / Seconds : ${sec}`),
                     this._icons.off,
                     true
                 );
             } else {
                 this.CtrlNotify.updateNotify(
                     this.notifyCounting,
-                    _('EasyScreenCast -> Recording in progress / Seconds passed : ') + sec,
+                    _('Recording ... / Seconds passed : ') + sec,
                     this._icons.on,
                     false
                 );
@@ -831,8 +818,11 @@ const EasyScreenCastIndicator = GObject.registerClass({
      * @private
      */
     _openExtensionPreferences() {
-        // openPrefs is available since Gnome Shell 3.36.2
-        ExtensionUtils.openPrefs();
+        try {
+            this._extension.openPreferences();
+        } catch (e) {
+            Lib.TalkativeLog(`Failed to open preferences: ${e}`);
+        }
     }
 
     /**
@@ -841,11 +831,10 @@ const EasyScreenCastIndicator = GObject.registerClass({
     _onDelayTimeChanged() {
         const secDelay = Math.floor(this.TimeSlider.value * 100);
         this._settings.setOption(Settings.TIME_DELAY_SETTING_KEY, secDelay);
-        if (secDelay > 0) {
+        if (secDelay > 0)
             this.smDelayRec.label.text = secDelay + _(' sec. delay before recording');
-        } else {
+        else
             this.smDelayRec.label.text = _('Start recording immediately');
-        }
     }
 
     /**
@@ -858,11 +847,10 @@ const EasyScreenCastIndicator = GObject.registerClass({
 
         if (isActive === true) {
             if (indicators === 0 || indicators === 1) {
-                if (focus === true) {
+                if (focus === true)
                     this.indicatorIcon.set_gicon(this._icons.onSel);
-                } else {
+                else
                     this.indicatorIcon.set_gicon(this._icons.on);
-                }
             } else if (this._settings.getOption('b', Settings.ACTIVE_SHORTCUT_SETTING_KEY)) {
                 this.indicatorIcon.set_gicon(null);
             } else if (focus === true) {
@@ -873,11 +861,10 @@ const EasyScreenCastIndicator = GObject.registerClass({
 
             this.RecordingLabel.set_text(_('Stop recording'));
         } else {
-            if (focus === true) {
+            if (focus === true)
                 this.indicatorIcon.set_gicon(this._icons.offSel);
-            } else {
+            else
                 this.indicatorIcon.set_gicon(this._icons.off);
-            }
 
             this.RecordingLabel.set_text(_('Start recording'));
         }
@@ -893,15 +880,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
             return;
         }
 
-        var stdMenu;
-
-        if (Main.panel.statusArea.quickSettings) {
-            // since gnome 43: aggregateMenu -> quickSettings
-            stdMenu = Main.panel.statusArea.quickSettings;
-        } else {
-            stdMenu = Main.panel.statusArea.aggregateMenu;
-        }
-
+        var stdMenu = Main.panel.statusArea.quickSettings;
         if (stdMenu === undefined) {
             Lib.TalkativeLog('-*-no quickSettings or aggregateMenu in Main.panel.statusArea');
             return;
@@ -910,8 +889,7 @@ const EasyScreenCastIndicator = GObject.registerClass({
             Lib.TalkativeLog('-*-no _remoteAccess indicator applet found');
             return;
         }
-        // since gnome 43: _recordingIndicator -> _indicator
-        var indicator = stdMenu._remoteAccess._indicator || stdMenu._remoteAccess._recordingIndicator;
+        var indicator = stdMenu._remoteAccess._indicator;
         if (indicator === undefined) {
             Lib.TalkativeLog('-*-no _indicator or _recordingIndicator found');
             return;
@@ -991,9 +969,8 @@ const EasyScreenCastIndicator = GObject.registerClass({
     destroy() {
         Lib.TalkativeLog('-*-destroy indicator called');
 
-        if (isActive) {
+        if (isActive)
             isActive = false;
-        }
 
         if (this._settings) {
             this._settings.destroy();
@@ -1004,48 +981,54 @@ const EasyScreenCastIndicator = GObject.registerClass({
     }
 });
 
-/**
- *
- */
-function init() {
-    ExtensionUtils.initTranslations();
-}
+export default class EasyScreenCast extends Extension {
+    /**
+     *
+     */
+    enable() {
+        Lib.TalkativeLog('-*-enableExtension called');
+        Lib.TalkativeLog(`-*-version: ${this.metadata.version}`);
+        Lib.TalkativeLog(`-*-install path: ${this.path}`);
+        Lib.TalkativeLog(`-*-version (package.json): ${Lib.getFullVersion()}`);
 
-/**
- *
- */
-function enable() {
-    Lib.TalkativeLog('-*-enableExtension called');
-    Lib.TalkativeLog(`-*-version: ${Me.metadata.version}`);
-    Lib.TalkativeLog(`-*-install path: ${Me.path}`);
-    Lib.TalkativeLog(`-*-version (package.json): ${Lib.getFullVersion()}`);
+        if (Indicator === null || Indicator === undefined) {
+            Lib.TalkativeLog('-*-create indicator');
 
-    if (Indicator === null || Indicator === undefined) {
-        Lib.TalkativeLog('-*-create indicator');
+            Indicator = new EasyScreenCastIndicator(this);
+            Main.panel.addToStatusArea('EasyScreenCast-indicator', Indicator);
+        }
 
-        Indicator = new EasyScreenCastIndicator();
-        Main.panel.addToStatusArea('EasyScreenCast-indicator', Indicator);
+        Indicator._enable();
     }
 
-    Indicator._enable();
-}
+    /**
+     *
+     */
+    disable() {
+        Lib.TalkativeLog('-*-disableExtension called');
 
-/**
- *
- */
-function disable() {
-    Lib.TalkativeLog('-*-disableExtension called');
+        if (timerD !== null) {
+            Lib.TalkativeLog('-*-timerD stopped');
+            timerD.stop();
+            timerD = null;
+        }
 
-    if (timerD !== null) {
-        Lib.TalkativeLog('-*-timerD stoped');
-        timerD.stop();
-    }
+        // this might happen, if the extension is disabled during recording
+        if (timerC !== null) {
+            // stop counting rec
+            timerC.halt();
+            timerC = null;
+        }
 
-    if (Indicator !== null) {
-        Lib.TalkativeLog('-*-indicator call destroy');
 
-        Indicator._disable();
-        Indicator.destroy();
-        Indicator = null;
+        if (Indicator !== null) {
+            Lib.TalkativeLog('-*-indicator call destroy');
+
+            Indicator._disable();
+            Indicator.destroy();
+            Indicator = null;
+        }
     }
 }
+
+export {Indicator};
